@@ -674,9 +674,9 @@ _events[32] = ColormapNotifyEvent
 class ClientMessageData(xcffib.Union):
     def __init__(self, unpacker):
         xcffib.Union.__init__(self, unpacker)
-        self.data8 = xcffib.List(unpacker, "B", 20)
-        self.data16 = xcffib.List(unpacker, "H", 10)
-        self.data32 = xcffib.List(unpacker, "I", 5)
+        self.data8 = xcffib.List(unpacker.copy(), "B", 20)
+        self.data16 = xcffib.List(unpacker.copy(), "H", 10)
+        self.data32 = xcffib.List(unpacker.copy(), "I", 5)
 class ClientMessageEvent(xcffib.Event):
     def __init__(self, unpacker):
         xcffib.Event.__init__(self, unpacker)
